@@ -31,9 +31,7 @@ use Math::Symbolic::ExportConstants qw/:all/;
 
 use base 'Math::Symbolic::Base';
 
-use overload '""' => sub{ $_[0]->to_string() };
-
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 =head1 METHODS
 
@@ -186,6 +184,8 @@ __END__
 
 Steffen Mueller, E<lt>symbolic-module at steffen-mueller dot netE<gt>
 
+New versions of this module can be found on http://steffen-mueller.net or CPAN.
+
 =head1 SEE ALSO
 
 L<Math::Symbolic>
